;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "google-this" "20250407.1500"
  "A set of functions and bindings to google under point."
  '((emacs "24.1"))
  :url "http://github.com/Malabarba/emacs-google-this"
  :commit "abdcb565503844e2146de42ab5ba898e90a2bb09"
  :revdesc "abdcb5655038"
  :keywords '("convenience" "hypermedia")
  :authors '(("Artur Malabarba" . "bruce.connor.am@gmail.com"))
  :maintainers '(("Artur Malabarba" . "bruce.connor.am@gmail.com")))
